# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"parser": "cli.ipynb",
         "main": "cli.ipynb",
         "SL_REGEX": "slideslive.ipynb",
         "SL_INFO": "slideslive.ipynb",
         "SL_HTML": "slideslive.ipynb",
         "SL_CDN": "slideslive.ipynb",
         "YODA_CDN": "slideslive.ipynb",
         "url2id": "slideslive.ipynb",
         "get_sl_info": "slideslive.ipynb",
         "parse_slide_xml": "slideslive.ipynb",
         "get_slide_metadata": "slideslive.ipynb",
         "get_urls": "slideslive.ipynb",
         "download_slides": "slideslive.ipynb",
         "ffmpeg_concat_script": "slideslive.ipynb",
         "compose_ffmpeg_video": "slideslive.ipynb",
         "SlidesLive": "slideslive.ipynb"}

modules = ["cli.py",
           "slideslive.py"]

doc_url = "https://So-Cool.github.io/myslideslive/"

git_url = "https://github.com/So-Cool/myslideslive/tree/master/"

def custom_doc_links(name): return None
